@@ -10,10 +10,6 @@
 # Copyright © Semantyk 2020. All rights reserved.
 ##################################################
 
-from . import graph
-from . import model
-from . import resource
+from . import namespace
 
-from .graph import *
-from .model import *
-from .resource import *
\ No newline at end of file
+from .namespace import *
\ No newline at end of file
